%define versionmajor 6
%define versionminor 5
%define versionpatch 2

%if 0%{!?mkrel:1}
%define mkrel(c) %{1}%{?dist}
%endif

Summary: 	Full-featured POP/IMAP mail retrieval daemon
Name:		fetchmail
Version:	%{versionmajor}.%{versionminor}.%{versionpatch}
Release:	%mkrel 1
License: 	GPLv2
Group:		Networking/Mail
URL: 		https://www.fetchmail.info
Source0:	https://gitlab.com/fetchmail/fetchmail/-/archive/%{version}/%{name}-%{version}.tar.bz2
# Be sure to generate with `gpg2 -ab <file>`
Source2:	%{name}-%{version}.tar.bz2.asc
Source4:	fetchmail.sysconfig
Source5:	fetchmail.service
Source7:	fetchmail.png
Patch0:		fetchmail-5.7.0-nlsfix.patch

%if 0%{!?_iconsdir:1}
%define iconsdir %{_datarootdir}/icons
%endif

%if "%{version}" >= "6.5"
%global buildsystem meson
%else
%global buildsystem autotools
%endif

%if "%{buildsystem}" == "meson"
BuildRequires:  meson >= 1.3.0
#BuildRequires:  asciidoc,htmldoc,pandoc,python3dist(docutils)
%else
BuildRequires:	autoconf >= 2.71
BuildRequires:	automake
BuildRequires:  libtool
%endif
BuildRequires:  (gcc or clang)
BuildRequires:	bison
BuildRequires:	flex
BuildRequires:	gettext
BuildRequires:	gettext-devel
BuildRequires:  lynx
BuildRequires:	(openssl-devel >= 3.0.9 or pkgconfig(openssl) >= 3.0.9)
BuildRequires:  pkgconfig(krb5)
BuildRequires:	python3
# By default, fetchmail sends the mail to a local mail server.
Requires:       (mail-server or exim or postfix or sendmail)
# The mail server will then send the mail to a delivery agent (based on
# ~/.forward). The delivery agent can also be used directly.
Requires: 	(MailTransportAgent or maildrop or procmail)
# Not much use without a mail client. Elmo and alpine are the modern clones of
# elm and pine, respectively.
Recommends:     (mailx or mutt or neomutt or elmo or alpine)
Obsoletes:	fetchyahoo < 2.14.9-2

%description
Fetchmail is a free, full-featured, robust, and well-documented remote mail
retrieval and forwarding utility intended to be used over on-demand TCP/IP
links (such as SLIP or PPP connections).

It retrieves mail from remote mail servers and forwards it to your local
(client) machine's delivery system, so it can then be read by normal
mail user agents such as Mutt, Elm, Pine, (X)Emacs/Gnus or Mailx.

%if %{versionmajor} < 7
It comes with an interactive GUI configuration tool suitable for end-users.

Fetchmail supports every remote-mail protocol currently in use on the
Internet (POP2, POP3, RPOP, APOP, KPOP, all IMAPs, ESMTP ETRN) for
Internet (POP3, RPOP, APOP, KPOP, all IMAPs, ESMTP ETRN) for
retrieval.  Then Fetchmail forwards the mail through SMTP, so you can
read it through your normal mail client.
%else
Fetchmail supports all standard mail-retrieval protocols in use on the 
Internet: POP3, IMAP4rev1 (also IMAP4), ETRN, and ODMR. On the output side, 
fetchmail supports ESMTP/SMTP, LMTP, and invocation of a local delivery agent.

Fetchmail also fully supports authentication via GSSAPI, Kerberos 5, 
RFC1938 one-time passwords, Compuserve's POP3 with RPA, Microsoft's NTLM, Demon 
Internet's SDPS, or CRAM-MD5 authentication a la RFC2195.

Fetchmail supports end-to-end encryption with OpenSSL or wolfSSL. Do
read README.SSL for details on fetchmail's configuration and
README.SSL-SERVER for server-side requirements.
%endif

%package -n fetchmailconf
Summary: 	A utility for graphically configuring your fetchmail preferences
Group: 		System/Networking
Requires: 	tkinter3
Requires: 	python3dist(future)
Requires: 	%{name} = %{version}


%description -n fetchmailconf
Fetchmailconf is a TCL/TK application for graphically configuring
your ~/.fetchmailrc preferences file.
}
Fetchmail has many options which can be daunting to the new user.

This utility takes some of the guesswork and hassle out of setting up
fetchmail.

%package daemon
Summary:	SySV init script for demonize fetchmail for retrieving emails
Group:		System/Base
Requires:	%{name} = %{version}
Requires(preun): rpm-helper
Requires(post): rpm-helper

%description daemon
Systemd service for fetchmail for sucking emails.

%prep
%autosetup -p1

%build
%if 0%{?serverbuild:1}
# Just sets up CFLAGS; fetchmail should compile fine without them.
%serverbuild
%endif
%if "%{buildsystem}" == "meson"
touch fetchmail.tarball # Don't require a boatload of tools to rebuild the documentation
# The Meson system of fetchmail seems to lack any options.
%meson
export MESON_DIST_ROOT=. MESON_BUILD_ROOT=./build
./meson-dist-script.sh
%meson_build
%else
./autogen.sh
%configure  \
%if %{versionmajor} < 7
	--enable-POP2		\
%endif
	--enable-RPA		\
	--enable-NTLM		\
	--enable-SDPS           \
	--with-gssapi		\
	--with-kerberos5	\
	--with-ssl=%{_prefix}	\
	--with-python=%{_prefix}/python3

# (tv) do not use %%make in order to workaround buggy parallel build:
%__make all FAQ FEATURES NOTES
%endif

%install

%if "%{buildsystem}" == "meson"
%meson_install
%else
%make_install
%endif

mkdir -p %{buildroot}{%_libdir/rhs/control-panel,%_datadir/applets/Administration} \
	%{buildroot}{%_sysconfdir/{X11/wmconfig,sysconfig},%_mandir/man1,%_unitdir}

install rh-config/*.{xpm,init} %{buildroot}%{_libdir}/rhs/control-panel

install -m0644 %SOURCE4 %{buildroot}%{_sysconfdir}/sysconfig/fetchmail
install -m0755 %SOURCE5 %{buildroot}%{_unitdir}/fetchmail.service
sed -i -e 's,^#!/usr/bin/env python,#!/usr/bin/env python3,g' %{buildroot}%{python3_sitelib}/fetchmailconf.py

echo -e "# Put here each user config\n" > %{buildroot}/etc/fetchmailrc

# Menu entry
mkdir -p %{buildroot}%{_iconsdir}/hicolor/64x64/apps
install -m 0644 %{SOURCE7} %{buildroot}%{_iconsdir}/hicolor/64x64/apps/

mkdir -p $RPM_BUILD_ROOT%{_datadir}/applications
cat > $RPM_BUILD_ROOT%{_datadir}/applications/%{name}.desktop << EOF
[Desktop Entry]
Name=Fetchmailconf
Comment=Full-featured POP/IMAP mail retrieval daemon
Exec=%{name}
Icon=%{name}
Terminal=false
Type=Application
Categories=Settings;
EOF

%find_lang %name

cat > README.fetchmail-conf <<EOF
Fetchmailconf is a TCL/TK application for graphically configuring your
~/.fetchmailrc preferences file.

Fetchmail has many options which can be daunting to the new user.


This utility takes some of the guesswork and hassle out of setting up
fetchmail.
EOF

%post -n fetchmail-daemon
#%systemd_post fetchmail
%_post_service fetchmail

#%preun -n fetchmail-daemon
#%systemd_preun fetchmail

#%postun -n fetchmail-daemon
#%systemd_postun_with_restart fetchmail
%_preun_service fetchmail

%files -f %name.lang
%if "%{buildsystem}" != "meson"
%doc FAQ FEATURES NOTES
%doc INSTALL NEWS README*
%doc contrib fetchmail-features.html fetchmail-FAQ.html design-notes.html
%else
%{_docdir}/%{name}/
%endif
%exclude %{_docdir}/%{name}/README.%{name}-conf
%license COPYING
%attr(2755, root, mail) %{_bindir}/%{name}
%{_mandir}/man1/%{name}.1*

%files -n fetchmailconf
%doc README.%{name}-conf
%{_libdir}/rhs/control-panel/*
%{_bindir}/%{name}conf
%{_mandir}/man1/%{name}conf.1*
%{_datadir}/applications/%{name}.desktop
%{_iconsdir}/hicolor/64x64/apps/%{name}.png
%{python3_sitelib}/*

%files daemon
%attr(600,mail,mail) %config(noreplace,missingok) %{_sysconfdir}/%{name}rc
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}
%{_unitdir}/%{name}.service

%changelog
* Wed Dec 08 2021 neoclust <neoclust> 6.4.24-1.mga8
  + Revision: 1761230
  - New version 6.4.24: Fixes CVE-2021-39272 (mga#29420)
  - Add P100: Fixes CVE-2021-36386 (mga#29297)
  + tmb <tmb>
  - fix CVE-2021-36386 regression (mga#29349)


* Sun Jul 19 2020 wally <wally> 6.4.8-4.mga8
  + Revision: 1607191
  - increase systemd service default polling interval to 300 seconds

* Sat Jul 18 2020 wally <wally> 6.4.8-3.mga8
  + Revision: 1607010
  - drop norootwarning patch
  - log to syslog when used as a systemd service

* Sat Jul 18 2020 wally <wally> 6.4.8-2.mga8
  + Revision: 1606903
  - switch from old init script to systemd service (mga#26969)

* Sat Jul 18 2020 wally <wally> 6.4.8-1.mga8
  + Revision: 1606898
  - new version 6.4.8


* Wed Mar 25 2020 danf <danf> 6.4.2-1.mga8
  + Revision: 1559577
  - Upgraded to 6.4.2
  + umeabot <umeabot>
  - Mageia 8 Mass Rebuild
  + wally <wally>
  - replace deprecated %%configure2_5x
